/*
 * Cstdint.h
 *
 * ACCU Overload 95, February 2010
 *
 * One approach to using hardware registers in C++.
 *
 * Martin Moene, http://www.eld.physics.LeidenUniv.nl/~moene/
 */

#ifndef G_CSTDINT_H
#define G_CSTDINT_H

/**
 * \file Cstdint.h
 * C99 standard (and C++0x) sized types, such as std::int8_t, std::uint16_t.
 */

#include <boost/cstdint.hpp>   // int8_t etc.

/**
 * the std namespace.
 */
namespace std {

/* *
 * \addtogroup register_cstdint
 * @{
 */

/**
 * \typedef boost::int8_t std::int8_t;
 * 8-bit signed type (-128--127).
 */
using boost::int8_t;

/**
 * \typedef std::uint8_t
 * 8-bit unsigned type (0--255).
 */
using boost::uint8_t;

/**
 * \typedef std::int16_t
 * 16-bit signed type (-32768--32767).
 */
using boost::int16_t;

/**
 * \typedef std::uint16_t
 * 16-bit unsigned type (0--65535).
 */
using boost::uint16_t;

/**
 * \typedef std::int32_t
 * 32-bit signed type (-(2^31)--(2^31-1)).
 */
using boost::int32_t;

/**
 * \typedef std::uint32_t
 * 32-bit unsigned type (0--(2^32)-1).
 */
using boost::uint32_t;

///**
// * \typedef std::byte_t
// */
//typedef boost::uint8_t byte_t;

/// @} register_cstdint

} // namespace std

#endif // G_CSTDINT_H

/*
 * end of file
 */
