/*
 * MemoryChannel.h
 *
 * ACCU Overload 95, February 2010
 *
 * One approach to using hardware registers in C++.
 *
 * Martin Moene, http://www.eld.physics.LeidenUniv.nl/~moene/
 */

#ifndef G_MEMORYCHANNEL_H
#define G_MEMORYCHANNEL_H

/**
 * \file Code/MemoryChannel.h
 * Transport for memory mapped registers.
 */

namespace spm {

/**
 * transport for memory mapped register (implements Channel Concept);
 * note registers are assumed volatile.
 */
template < typename D, typename /* A unused */ >
class MemoryChannel
{
public:
   /**
    * the data type.
    */
   typedef D DataType;

   /**
    * the register type (volatile).
    */
   typedef volatile DataType RegisterType;

   /**
    * the address type.
    */
   typedef RegisterType* AddressType;

   /**
    * read data from given address.
    */
   static DataType read( AddressType address )
   {
      return *address;
   }

   /**
    * write data to given address.
    */
   static void write( AddressType address, DataType data )
   {
      *address = data;
   }
};

} // namespace spm {

#endif // G_MEMORYCHANNEL_H

/*
 * end of file
 */
