/*
 * Shims.h
 *
 * ACCU Overload 95, February 2010
 *
 * One approach to using hardware registers in C++.
 *
 * Martin Moene, http://www.eld.physics.LeidenUniv.nl/~moene/
 */

#ifndef G_SHIMS_H
#define G_SHIMS_H

/**
 * \file Shims.h
 * conversion shims, such as to_string() and to_int().
 */

// system includes
#include <string>             // for std::string
#include <cstdlib>            // for std::strtol()

namespace spm {

/* *
 * \addtogroup register_shims
 * @{
 */

/**
 * convert signed integral to std::string [base 10].
 */
inline const std::string to_string( const long x, const int base = 10 )
{
   char buf[65];

   return _ltoa( x, buf, base );
}

/**
 * convert signed integral to std::string [base 10].
 */
inline const char* to_cstr( const long x, const int base = 10 )
{
   return to_string( x, base ).c_str();
}

/**
 * convert c-string to c-string.
 */
inline const char* to_cstr( const char* s )
{
   return s;
}

/**
 * convert std:string to c-string.
 */
inline const char* to_cstr( const std::string& s )
{
   return s.c_str();
}

/**
 * convert integer to integer (int).
 */
inline const int to_int( const int x )
{
   return x;
}

/**
 * convert integer to integer (long).
 */
inline const long to_int( const long x )
{
   return x;
}

/**
 * convert string to integer; 123 decimal, 012 octal, 0x12 hexadecimal.
 */
inline const long to_int( const std::string s )
{
   return std::strtol( to_cstr( s ), 0, 0 );
}

///@} register_shims

} // namespace spm {

#endif // G_SHIMS_H

/*
 * end of file
 */
