/*
 * Test-assembly.h
 *
 * ACCU Overload 95, February 2010
 *
 * One approach to using hardware registers in C++.
 *
 * Martin Moene, http://www.eld.physics.LeidenUniv.nl/~moene/
 */

/**
 * \file Test-assembly.cpp
 * Assign a value to a register in various ways to inspect its resulting assembly code.
 */

#include <iostream>        // std::cout

#include "Register.h"      // spm::Register
#include "Cstdint.h"       // std::uint32_t

typedef std::uint32_t DataType;  // 32-bit PCI address type

typedef spm::Register< DataType > RegisterType;
typedef RegisterType::AddressType AddressType;

const AddressType base   ( reinterpret_cast<AddressType>( 0x77 ) );
const int         offset ( 0x33 );
const DataType    initial( 0xe5 );
const DataType    value  ( 0x44 );

int main()
{
   RegisterType reg( base, offset, initial );
   reg.write_nc( value );  // write and cache value
   reg.write();            // rewrite cached value
   reg = value+0x22;       // write and cache value+22
}

/*
; 31   :    RegisterType reg( base, offset, initial );

	push	229					; 000000e5H
	push	51					; 00000033H
	push	119					; 00000077H
	lea	ecx, DWORD PTR _reg$[esp+48]
	call	??0?$Register@KPAKVMemoryChannelPolicy@spm@@@spm@@QAE@PAKHK@Z ; spm::Register<unsigned long,unsigned long *,spm::MemoryChannelPolicy>::Register<unsigned long,unsigned long *,spm::MemoryChannelPolicy>
	mov	DWORD PTR __$EHRec$[esp+44], 0

; 32   :    reg.write_nc( value );  // write and cache value

	mov	eax, DWORD PTR _reg$[esp+48]
	mov	DWORD PTR [eax], 68			; 00000044H

; 33   :    reg.write();            // rewrite cached value

	mov	ecx, DWORD PTR _reg$[esp+52]
	mov	edx, DWORD PTR _reg$[esp+48]
	mov	DWORD PTR [edx], ecx

; 34   :    reg = value+22;         // write and cache value+22

	mov	eax, DWORD PTR _reg$[esp+48]
	mov	DWORD PTR _reg$[esp+52], 102		; 00000066H
	mov	DWORD PTR [eax], 102			; 00000066H
*/

// end of file
