/*
 * Test-inspect.cpp
 *
 * ACCU Overload 95, February 2010
 *
 * One approach to using hardware registers in C++.
 *
 * Martin Moene, http://www.eld.physics.LeidenUniv.nl/~moene/
 */

/**
 * \file Test-inspect.cpp
 * Do a single register assignment to inspect what happens (no expectations defined).
 */

#include <iostream>        // std::cout

#include "Register.h"      // class Register
#include "RegisterSpy.h"   // class RegisterSpy
#include "Test-common.h"   // SPM_TEST_INSPECT_MESSAGE_

#include <boost/test/unit_test.hpp> // Boost.Test

typedef int DataType;
typedef int AddressType;

typedef spm::tdd::RegisterSpy< DataType, AddressType > RegisterSpyType;
typedef spm::Register< DataType, AddressType, RegisterSpyType > RegisterType;

const AddressType base   ( 0x10 );
const int         offset ( 0x07 );
const DataType    initial( 0xe5 );
const AddressType address( RegisterType::computeAddress( base, offset ) );

BOOST_AUTO_TEST_SUITE( Register )
BOOST_AUTO_TEST_SUITE( Inspect )

struct Fixture
{
   Fixture() : spy( "Inspect>" ), reg( spy, base, offset, initial ) {;}
   // show and inspect register interaction
   ~Fixture() { SPM_TEST_MESSAGE( spy );}

   RegisterSpyType spy;
   RegisterType    reg;
};

BOOST_FIXTURE_TEST_CASE( testThatRegisterAssignmentWritesProperValueToRegister, Fixture )
{
   SPM_TESTCASE_MESSAGE( "Inspect> ", " (Inspect):" );
   const DataType value( 0x123 );
   spy.relax();   // no expectation specifications required
   reg = value;
}

BOOST_AUTO_TEST_SUITE_END() // Inspect
BOOST_AUTO_TEST_SUITE_END() // Register

/*
 * end of file
 */
