/*
 * Test-minimal.cpp
 *
 * ACCU Overload 95, February 2010
 *
 * One approach to using hardware registers in C++.
 *
 * Martin Moene, http://www.eld.physics.LeidenUniv.nl/~moene/
 */

/**
 * \file Test-minimal.cpp
 * Show a single test with expectation defined.
 */

#include <iostream>        // std::cout

#include "Register.h"      // class Register
#include "RegisterSpy.h"   // class RegisterSpy
#include "Test-common.h"   // SPM_TEST_INSPECT_MESSAGE

#include <boost/test/unit_test.hpp> // Boost.Test

typedef int DataType;
typedef int AddressType;

typedef spm::tdd::RegisterSpy< DataType, AddressType > RegisterSpyType;
typedef spm::Register< DataType, AddressType, RegisterSpyType > RegisterType;

const AddressType base   ( 0x10 );
const int         offset ( 0x07 );
const DataType    initial( 0xe5 );
const AddressType address( RegisterType::computeAddress( base, offset ) );

BOOST_AUTO_TEST_SUITE( Register )
BOOST_AUTO_TEST_SUITE( Minimal )

struct Fixture
{
   Fixture() : spy( "Inspect>" ) , reg( spy, base, offset, initial ){;}
   ~Fixture() { SPM_TEST_MESSAGE( spy ); }

   RegisterSpyType spy;
   RegisterType    reg;
};

BOOST_FIXTURE_TEST_CASE( testThatRegisterAssignmentWritesCorrectValueToRegister, Fixture )
{
   SPM_TESTCASE_MESSAGE( "Inspect> ", " (Pass):" );
   const DataType value( 0x123 );
   spy.addWriteExpectation( address, value, "assign value to register" );
   reg = value;
   SPM_CHECK_REGISTER_SPY_EXPECTATIONS( spy );
}

BOOST_AUTO_TEST_SUITE_END() // Minimal
BOOST_AUTO_TEST_SUITE_END() // Register

/*
 * end of file
 */
