#
# mk-performance-computation.py
#
# ACCU Overload 95, February 2010
#
# One approach to using hardware registers in C++.
#
# Martin Moene, http://www.eld.physics.LeidenUniv.nl/~moene/
#

## \file mk-performance-computation.py
# compute mean and median execution times from file given on the commandline.
#

import string
import sys

#
# compute mean and median execution times from file given on the commandline.
#
# File format:
# Running 18 test cases...
#  1	2.73 [ns]	*p = x	timePointerWriteNoCache
#  2	3.48 [ns]	reg.write_nc( x )	timeRegisterWriteNoCache
#  3	 2.8 [ns]	*p = cache = x	timePointerWriteAndCache
#
# Example output:
# #       samples sum     mean    median
# 1       100     292.32  2.9232  2.8
# 2       100     304.93  3.0493  2.815
# 3       100     296.54  2.9654  2.81
def main( argv ):
   if len( argv ) <> 2:
      print "Usage: {0} file-with-test-output".format( sys.argv[0] )
      exit( 1 )

   filename = sys.argv[1]
   f        = open( filename, 'r')
   lines    = f.readlines()

   times = {}
   for text in lines:
      fields = string.split( text )
      if ( isnumeric( fields[0] ) ):
         ndx = int  ( fields[0] )
         val = float( fields[1] )

         if ( ndx in times ):
            times[ ndx ].append(val)
         else:
            times[ ndx ] = [val]

   print "#\tsamples\tsum\tmean\tmedian\tmin\tmax"
   for k, v in times.iteritems():
      print k, "\t", len(v), "\t", sum(v), "\t", mean(v), "\t", median(v), "\t", min(v), "\t", max(v)

#
# true if text starts with digit:
#
def isnumeric(x):
   return x[0] in string.digits

#
# return mean of list:
#
def mean( values ):
   return sum( values ) / len( values )

#
# http://codecomments.wordpress.com/2008/03/17/simple-method-to-calculate-median-in-python/
#
def median( values ):
  theValues = sorted(values)

  if len( theValues ) % 2 == 1:
    return theValues[( len(theValues)+1 ) / 2 - 1 ]
  else:
    lower = theValues[ len(theValues) / 2 - 1 ]
    upper = theValues[ len(theValues) / 2 ]

    return float( lower + upper ) / 2

#
# main line:
#
if __name__ == "__main__":
    main( sys.argv )

#
# end of file
#
