// g++     -O2 -I. -c Test-access.cpp
// cl -FAs -O2 -I. -c Test-access.cpp

/**
 * \file Code2/Test-access.cpp
 * Test register read-write properties with memory mapped register access.
 */

#include "Register.h"

typedef int DataType;
typedef DataType* AddressType;

typedef spm::MemoryChannel< DataType, AddressType > RwChannelType;

typedef       spm::Register2< DataType, AddressType, RwChannelType, spm::rap::ReadWrite > RwRegisterType;
typedef       spm::Register2< DataType, AddressType, RwChannelType, spm::rap::WriteOnly > WoRegisterType;
typedef const spm::Register2< DataType, AddressType, RwChannelType, spm::rap::ReadOnly  > RoRegisterType;

int x;
const AddressType  k_base   ( &x );
const int          k_offset (  0 );
const AddressType  k_address( k_base + k_offset );
const DataType     k_default( 0xe5 );

int main()
{
   RwRegisterType rw_reg( k_base, k_offset, k_default );
   WoRegisterType wo_reg( k_base, k_offset, k_default );
   RoRegisterType ro_reg( k_base, k_offset, k_default );

// cannot copy-initialise a register:
// RwRegisterType rw_reg2( rw_reg );

// cannot copy-assign a register:
// RwRegisterType rw_reg3( k_base, k_offset, k_default ); rw_reg3 = rw_reg;

   DataType rw_data = rw_reg;
// DataType wo_data = wo_reg; // cannot read a write-only register:
   DataType ro_data = ro_reg;

   rw_reg  = 123;
   wo_reg  = 345;
// ro_reg  = 456; // cannot assign a read-only register:
}

