@echo off
rem
rem mk.bat
rem
rem ACCU Overload 95, February 2010
rem
rem One approach to using hardware registers in C++.
rem
rem Martin Moene, http://www.eld.physics.LeidenUniv.nl/~moene/
rem

setlocal

set  PROG_NAME=%0
set    SVN_DIR=Register
set EXPORT_DIR=Accu.Overload95.Register
set  TEST_PROG=Code\Test.exe

rem
rem handle options:
rem
if "X"=="X%*" (
   call :usage
   goto end
)

rem
rem test:
rem
if "test"=="%1" (
   call :subtest
   goto end
)

rem
rem inspect:
rem
if "inspect"=="%1" (
   call :subinspect
   goto end
)

rem
rem build:
rem
if "build"=="%1" (
   call :subcompile
   call :subdocumentation
   goto end
)

rem
rem compile:
rem
if "compile"=="%1" (
   call :subcompile
   goto end
)

rem
rem gcc:
rem
if "gcc"=="%1" (
   call :subgcc
   goto end
)

rem
rem dist:
rem
if "dist"=="%1" (
   call :subbuild
   call :subdcln
   call :subdist
   goto end
)

rem
rem clean:
rem
:clean
if "clean"=="%1" (
   call :subcln
   goto end
)

rem
rem distclean:
rem
:distclean
if "distclean"=="%1" (
   call :subdcln
   call :subcln
   goto end
)

rem
rem realclean:
rem
:realclean
if "realclean"=="%1" (
   call :subrcln
   call :subdcln
   call :subcln
   goto end
)

:error
echo %PROG_NAME%: unrecognized command '%1'.
echo.
call :usage
exit /b 1

:end
exit /b 0

rem
rem subroutines:
rem

:usage
echo Usage: %PROG_NAME% [option]
echo      test: run test program only showing errors (builds if needed)
echo   inspect: run test program showing messages (builds if needed)
echo     build: build programs and documentation using MS VC8 and doxygen
echo   compile: compile programs MS VC8
echo       gcc: compile programs using gcc to see its warnings
echo      dist: create distribution archive (tar.gz)
echo     clean: remove backup files
echo distclean: remove files not in distribution
echo realclean: remove all non-source files
exit /b

:subtest
if not exist %TEST_PROG% do call :subbuild
%TEST_PROG%
exit /b

:subinspect
if not exist %TEST_PROG% do call :subbuild
%TEST_PROG% --log_level=message
exit /b

:subbuild
call :subcompile
call :subdocumentation
exit /b

:subcompile
set DIRS=Code Code2
for %%d in ( %DIRS% ) do (

   cd %%d & call mk.bat
   if errorlevel 1 (
      cd ..
      exit /b 1
   )
   cd ..
)
exit /b

:subdocumentation
set DIRS=Documentation
echo Building documentation...
for %%d in ( %DIRS% ) do (
   cd %%d & call mk.bat
   if errorlevel 1 (
      cd ..
      exit /b 1
   )
   cd ..
)
exit /b

:subgcc
set DIRS=Code Code2
for %%d in ( %DIRS% ) do (
   cd %%d & call mk-gcc.bat
   if errorlevel 1 (
      cd ..
      exit /b 1
   )
   cd ..
)
exit /b

:subcln
del /s/q *.bak 2>nul
exit /b

:subdcln
set DIRS=Code Code2
for %%d in ( %DIRS% ) do (
   del %%d\*.asm 2>nul
   del %%d\*.o   2>nul
   del %%d\*.obj 2>nul
)
rmdir /s/q Documentation\html 2>nul
exit /b

:subrcln
del /q Documentation\*.chm 2>nul
exit /b

:subdist
cd ..
call :subclnexp
svn export %SVN_DIR% %EXPORT_DIR%
strip %SVN_DIR%\Code\*.exe
copy %SVN_DIR%\Code\*.exe %EXPORT_DIR%\Code >nul
copy %SVN_DIR%\Documentation\*.chm %EXPORT_DIR%\Documentation >nul
tar czvf %EXPORT_DIR%.tar.gz %EXPORT_DIR%
call :subclnexp
cd %SVN_DIR%
exit /b

:subclnexp
rmdir /s/q %EXPORT_DIR% 2>nul
exit /b

endlocal

rem
rem end of file
rem
